==> open-xchange-core_7.8.3.orig.tar.bz2: open-xchange-core-7.8.3/com.openexchange.net.ssl.config.impl/src/com/openexchange/net/ssl/config/impl/jslob/AcceptUntrustedCertificatesJSLobEntry.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.net.ssl.config.impl.jslob;

import java.util.Map;
import com.openexchange.context.ContextService;
import com.openexchange.exception.OXException;
import com.openexchange.jslob.JSlobEntry;
import com.openexchange.jslob.JSlobKeys;
import com.openexchange.net.ssl.config.UserAwareSSLConfigurationService;
import com.openexchange.session.Session;

/**
 * {@link AcceptUntrustedCertificatesJSLobEntry}
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since v7.8.3
 */
public class AcceptUntrustedCertificatesJSLobEntry implements JSlobEntry {

    static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AcceptUntrustedCertificatesJSLobEntry.class);

    private static final String LOB_NAMESPACE = "security";

    private ContextService contextService;
    private UserAwareSSLConfigurationService userAwareSSLConfigurationService;

    /**
     * Default constructor.
     * 
     * @param contextService
     */
    public AcceptUntrustedCertificatesJSLobEntry(ContextService contextService, UserAwareSSLConfigurationService userAwareSSLConfigurationService) {
        super();
        this.contextService = contextService;
        this.userAwareSSLConfigurationService = userAwareSSLConfigurationService;
    }

    @Override
    public String getKey() {
        return JSlobKeys.CORE;
    }

    @Override
    public String getPath() {
        return LOB_NAMESPACE + "/" + UserAwareSSLConfigurationService.USER_ATTRIBUTE_NAME;
    }

    @Override
    public boolean isWritable(Session session) throws OXException {
        return userAwareSSLConfigurationService.isAllowedToDefineTrustLevel(session.getUserId(), session.getContextId());
    }

    @Override
    public Object getValue(Session sessiond) throws OXException {
        boolean allowedToDefineTrustLevel = userAwareSSLConfigurationService.isAllowedToDefineTrustLevel(sessiond.getUserId(), sessiond.getContextId());
        if (!allowedToDefineTrustLevel) {
            return false;
        }

        return userAwareSSLConfigurationService.isTrustAll(sessiond.getUserId(), sessiond.getContextId());
    }

    @Override
    public void setValue(Object value, Session sessiond) throws OXException {
        boolean allowedToDefineTrustLevel = userAwareSSLConfigurationService.isAllowedToDefineTrustLevel(sessiond.getUserId(), sessiond.getContextId());

        if (!allowedToDefineTrustLevel) {
            LOG.debug("Setting {} has been disabled due to configuration ('" + UserAwareSSLConfigurationService.USER_CONFIG_ENABLED_PROPERTY + "'). The request will be ignored.", UserAwareSSLConfigurationService.USER_ATTRIBUTE_NAME);
            return;
        }
        userAwareSSLConfigurationService.setTrustAll(sessiond.getUserId(), contextService.getContext(sessiond.getContextId()), Boolean.parseBoolean(value.toString()));
    }

    @Override
    public Map<String, Object> metadata(Session session) throws OXException {
        // nothing special to add
        return null;
    }
}

==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.net.ssl.config.impl/src/com/openexchange/net/ssl/config/impl/jslob/AcceptUntrustedCertificatesJSLobEntry.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.net.ssl.config.impl.jslob;

import java.util.Map;
import com.openexchange.context.ContextService;
import com.openexchange.exception.OXException;
import com.openexchange.jslob.JSlobEntry;
import com.openexchange.jslob.JSlobKeys;
import com.openexchange.net.ssl.config.UserAwareSSLConfigurationService;
import com.openexchange.session.Session;

/**
 * {@link AcceptUntrustedCertificatesJSLobEntry}
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since v7.8.3
 */
public class AcceptUntrustedCertificatesJSLobEntry implements JSlobEntry {

    static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AcceptUntrustedCertificatesJSLobEntry.class);

    private static final String LOB_NAMESPACE = "security";

    private final ContextService contextService;
    private final UserAwareSSLConfigurationService userAwareSSLConfigurationService;

    /**
     * Default constructor.
     *
     * @param contextService
     */
    public AcceptUntrustedCertificatesJSLobEntry(ContextService contextService, UserAwareSSLConfigurationService userAwareSSLConfigurationService) {
        super();
        this.contextService = contextService;
        this.userAwareSSLConfigurationService = userAwareSSLConfigurationService;
    }

    @Override
    public String getKey() {
        return JSlobKeys.CORE;
    }

    @Override
    public String getPath() {
        return LOB_NAMESPACE + "/" + UserAwareSSLConfigurationService.USER_ATTRIBUTE_NAME;
    }

    @Override
    public boolean isWritable(Session session) throws OXException {
        return userAwareSSLConfigurationService.isAllowedToDefineTrustLevel(session.getUserId(), session.getContextId());
    }

    @Override
    public Object getValue(Session sessiond) throws OXException {
        boolean allowedToDefineTrustLevel = userAwareSSLConfigurationService.isAllowedToDefineTrustLevel(sessiond.getUserId(), sessiond.getContextId());
        if (!allowedToDefineTrustLevel) {
            return false;
        }

        return userAwareSSLConfigurationService.isTrustAll(sessiond.getUserId(), sessiond.getContextId());
    }

    @Override
    public void setValue(Object value, Session sessiond) throws OXException {
        boolean allowedToDefineTrustLevel = userAwareSSLConfigurationService.isAllowedToDefineTrustLevel(sessiond.getUserId(), sessiond.getContextId());

        if (!allowedToDefineTrustLevel) {
            LOG.debug("Setting {} has been disabled due to configuration ('{}'). The request will be ignored.", UserAwareSSLConfigurationService.USER_ATTRIBUTE_NAME, UserAwareSSLConfigurationService.USER_CONFIG_ENABLED_PROPERTY);
            return;
        }
        userAwareSSLConfigurationService.setTrustAll(sessiond.getUserId(), contextService.getContext(sessiond.getContextId()), Boolean.parseBoolean(value.toString()));
    }

    @Override
    public Map<String, Object> metadata(Session session) throws OXException {
        // nothing special to add
        return null;
    }
}
